diff --git a/Tests/GeoLib/TestOctTree.cpp b/Tests/GeoLib/TestOctTree.cpp
index ffa654a3bcb7b048db7722b263db5ba7e54a2615..5714e47c9d18d243f9e99e789e45022985a61034 100644
--- a/Tests/GeoLib/TestOctTree.cpp
+++ b/Tests/GeoLib/TestOctTree.cpp
@@ -246,7 +246,7 @@ TEST_F(GeoLibOctTree, TestWithEquidistantPoints3d)
 
 TEST_F(GeoLibOctTree, TestWithAlternatingPoints3d)
 {
-	// this case is not correctely handled by lexicographical sorting
+	// this case is not correctly handled by lexicographical sorting
 	double const eps(1e-1);
 	double const small_displacement(1e-2);
 	ps_ptr.push_back(new GeoLib::Point(0,0,0,0));
@@ -293,9 +293,9 @@ TEST_F(GeoLibOctTree, TestWithAlternatingPoints3d)
 	ASSERT_EQ(ps_ptr[2], ret_pnt);
 }
 
-TEST_F(GeoLibOctTree, TestSmallDistanceDifferentLeafes)
+TEST_F(GeoLibOctTree, TestSmallDistanceDifferentLeaves)
 {
 	// case where two points with a small distance but different OctTree leafes
 	// are inserted
 	double const eps(0.5);
 	std::vector<GeoLib::Point*> ps_ptr;
@@ -293,9 +293,9 @@ TEST_F(GeoLibOctTree, TestWithAlternatingPoints3d)
 {
-	// case where two points with a small distance but different OctTree leafes
+	// case where two points with a small distance but different OctTree leaves
 	// are inserted
 	double const eps(0.5);